# NotionAI Plus

NotionAI Plus is a browser extension that adds NotionAI's powerful features to any website you visit. With NotionAI Plus, you can easily analyze text, generate summaries, and perform sentiment analysis on any webpage.

## Features

- Analyze text, generate summaries, and perform sentiment analysis on any webpage using NotionAI's powerful features
- Backend engine support for `NotionAI`, `ChatGPT Web`, and `ChatGPT API`
- Support for all NotionAI built-in prompts
- Support for using custom prompts


## Usage

1. Install NotionAI Plus from the [Chrome Web Store](https://chrome.google.com/webstore/detail/notionai-plus/ilgkcoockdhdpkikaakkjacblhpmdmeo) or [Firefox Addon](https://addons.mozilla.org/en-US/firefox/addon/notionai-plus/)
2. Open the `options page` and set your `Notion space ID`
3. Open any webpage and use the shortcut `alt+k` to activate the extension
4. If you select some text and then use the shortcut `alt+k` to activate the extension, it will automatically fill the text in the input box.


## TODO

- [ ] Support for using custom prompts with shortcut and loading other prompts
- [ ] Support for saving results to Notion
- [ ] Support for summarizing articles on a page
- [ ] Support for summarizing videos on Youtube and Bilibili
- [ ] Support for setting default output language on the options page
- [ ] Improved UI design

## Contributing

NotionAI Plus is an open-source project and welcomes contributions from the community. Feel free to submit issues, feature requests, or pull requests on the [GitHub repository](https://github.com/Vaayne/NotionAI).

## License

NotionAI Plus is released under the [MIT License](https://github.com/NotionAI/notionai-plus/blob/main/LICENSE).
